Revision: 7766
Author: victormote
Date: 2006-07-07 19:24:28 -0700 (Fri, 07 Jul 2006)
ViewCVS: http://svn.sourceforge.net/foray/?rev=7766&view=rev
Log Message:
-----------
Make constructors public so that they can be created in external packages and registered with the broker.
Modified Paths:
--------------
trunk/foray/foray-common/src/java/org/foray/common/url/PropertyProtocolRegistration.java
trunk/foray/foray-common/src/java/org/foray/common/url/UniversalProtocolRegistration.java
Modified: trunk/foray/foray-common/src/java/org/foray/common/url/PropertyProtocolRegistration.java
===================================================================
--- trunk/foray/foray-common/src/java/org/foray/common/url/UniversalProtocolRegistration.java 2006-07-08 02:20:35 UTC (rev 7765)
+++ trunk/foray/foray-common/src/java/org/foray/common/url/UniversalProtocolRegistration.java 2006-07-08 02:24:28 UTC (rev 7766)
@@ -45,6 +45,12 @@
extends AbstractProtocolRegistration {
/**
+ * Constructor.
+ */
+ public UniversalProtocolRegistration() {
+ }
+
+ /**
* {@inheritDoc}
*/
public void doRegister(String protocol, URLStreamHandler handler) {
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
--- trunk/foray/foray-common/src/java/org/foray/common/url/PropertyProtocolRegistration.java 2006-07-08 02:20:35 UTC (rev 7765)
+++ trunk/foray/foray-common/src/java/org/foray/common/url/PropertyProtocolRegistration.java 2006-07-08 02:24:28 UTC (rev 7766)
@@ -27,12 +27,14 @@
package org.foray.common.url;
import java.net.URLStreamHandler;
+import java.net.URLStreamHandlerFactory;
import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;
/**
* An implementation of {#link ProtocolHandlerRegistry} which modifies the
* "java.protocol.handler.pkgs" property to register new URLStreamHandlers.
*/
public class PropertyProtocolRegistration
@@ -47,10 +49,10 @@
protected Map protocols = new HashMap();
/**
- * Package-private constructor.
+ * Constructor.
* @see ProtocolRegistrationBroker#getRegistry
*/
- PropertyProtocolRegistration() {
+ public PropertyProtocolRegistration() {
}
void doRegister(String protocol, URLStreamHandler handler) {
Modified: trunk/foray/foray-common/src/java/org/foray/common/url/UniversalProtocolRegistration.java
@@ -27,12 +27,14 @@
import java.util.StringTokenizer;
/**
- * An implementation of {#link ProtocolHandlerRegistry} which modifies the
+ * An implementation of {#link ProtocolHandlerRegistry} which does not attempt
+ * to use a {@link URLStreamHandlerFactory}, but instead modifies the
* "java.protocol.handler.pkgs" property to register new URLStreamHandlers.
*/
===================================================================